@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,10 +26,13 @@ class SieveEditorUtilTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit SieveEditorUtilTest(QObject *parent = Q_NULLPTR);
+    explicit SieveEditorUtilTest(QObject *parent = nullptr);
     ~SieveEditorUtilTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
+    void shouldTestSieveAccountSettingsDefaultValue();
+    void shouldSieveAccountSettingsMustBeValid();
+    void shouldBeEqual();
 };
 
 #endif // SIEVEEDITORUTILTEST_H
