@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,9 +26,20 @@ class ImportImapSettingsAkonadiCheckJobTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit ImportImapSettingsAkonadiCheckJobTest(QObject *parent = Q_NULLPTR);
+    explicit ImportImapSettingsAkonadiCheckJobTest(QObject *parent = nullptr);
     ~ImportImapSettingsAkonadiCheckJobTest();
+private Q_SLOTS:
+    void initTestCase();
+    void shouldHaveSettingsFiles();
+    void shouldHaveNotSettingsFiles();
+    void shouldHaveSettingsFilesImap();
+    void shouldHaveSettingsFilesMbox();
 
+    void shouldHaveImportSettings_data();
+    void shouldHaveImportSettings();
+
+    void shouldImportSieveSettings_data();
+    void shouldImportSieveSettings();
 };
 
 #endif // IMPORTIMAPSETTINGSAKONADICHECKJOBTEST_H
