@@ -37,11 +37,11 @@ ImportImapSettingSearchPage::ImportImapSettingSearchPage(QWidget *parent)
     mFoundProgramList = new QListWidget(this);
     mFoundProgramList->setObjectName(QStringLiteral("foundprogramlist"));
     mainLayout->addWidget(mFoundProgramList);
+    connect(mFoundProgramList, &QListWidget::itemChanged, this, &ImportImapSettingSearchPage::slotItemChanged);
 }
 
 ImportImapSettingSearchPage::~ImportImapSettingSearchPage()
 {
-
 }
 
 void ImportImapSettingSearchPage::setProgramList(const QStringList &lst)
@@ -65,3 +65,17 @@ QStringList ImportImapSettingSearchPage::selectedPrograms() const
     }
     return checkedItems;
 }
+
+void ImportImapSettingSearchPage::slotItemChanged()
+{
+    bool hasSelectedItem = false;
+    const int nbProgram = {mFoundProgramList->count()};
+    for (int i = 0; i < nbProgram; ++i) {
+        QListWidgetItem *item = mFoundProgramList->item(i);
+        if (item->checkState() == Qt::Checked) {
+            hasSelectedItem = true;
+            break;
+        }
+    }
+    Q_EMIT needToImportSettings(hasSelectedItem);
+}
