@@ -22,7 +22,7 @@
 #include "sieveeditorpagewidget.h"
 #include "sieveeditortabwidget.h"
 #include "sieveeditoremptytabwidgetlabel.h"
-#include "ksieveui/sieveeditor.h"
+#include <KSieveUi/SieveEditor>
 
 #include <KLocalizedString>
 #include <KConfigGroup>
@@ -122,9 +122,9 @@ void SieveEditorMainWidget::slotScriptRenamed(const QUrl &oldUrl, const QUrl &ne
     updateStackedWidget();
 }
 
-void SieveEditorMainWidget::slotCreateScriptPage(const QUrl &url, const QStringList &capabilities, bool isNewScript, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings)
+void SieveEditorMainWidget::slotCreateScriptPage(const KSieveUi::ManageSieveWidget::ScriptInfo &info, bool isNewScript)
 {
-    QWidget *page = hasExistingPage(url);
+    QWidget *page = hasExistingPage(info.currentUrl);
     if (page) {
         mTabWidget->setCurrentWidget(page);
     } else {
@@ -137,8 +137,8 @@ void SieveEditorMainWidget::slotCreateScriptPage(const QUrl &url, const QStringL
         connect(editor, &SieveEditorPageWidget::copyAvailable, this, &SieveEditorMainWidget::copyAvailable);
         connect(editor, &SieveEditorPageWidget::sieveEditorTabCurrentChanged, this, &SieveEditorMainWidget::sieveEditorTabCurrentChanged);
         editor->setIsNewScript(isNewScript);
-        editor->loadScript(url, capabilities, sieveImapAccountSettings);
-        mTabWidget->addTab(editor, url.fileName());
+        editor->loadScript(info);
+        mTabWidget->addTab(editor, info.currentUrl.fileName());
         mTabWidget->setCurrentWidget(editor);
         if (isNewScript) {
             editor->uploadScript(false, true);
