@@ -66,43 +66,43 @@ private:
     void initStatusBar();
     void readConfig();
     void setupActions();
-    SieveEditorCentralWidget *mMainWidget;
-    QAction *mDeleteScript;
-    QAction *mNewScript;
-    QAction *mEditScript;
-    QAction *mDesactivateScript;
-    QAction *mRefreshList;
-    QAction *mUploadScript;
-    QAction *mGoToLine;
-    QAction *mFindAction;
-    QAction *mReplaceAction;
-    QAction *mUndoAction;
-    QAction *mRedoAction;
-    QAction *mCopyAction;
-    QAction *mPasteAction;
-    QAction *mCutAction;
-    QAction *mSelectAllAction;
-    QAction *mSaveAsAction;
-    QAction *mImportAction;
-    QAction *mShareAction;
-    QAction *mSpellCheckAction;
-    QAction *mCheckSyntaxAction;
-    QAction *mCreateRulesGraphicallyAction;
-    QAction *mCommentAction;
-    QAction *mUncommentAction;
-    QAction *mZoomInAction;
-    QAction *mZoomOutAction;
-    QAction *mZoomResetAction;
-    QAction *mDebugSieveScriptAction;
-    QAction *mWrapTextAction;
-    QAction *mPrintAction;
-    QAction *mPrintPreviewAction;
-    PimCommon::KActionMenuChangeCase *mMenuChangeCaseAction;
+    SieveEditorCentralWidget *mMainWidget = nullptr;
+    QAction *mDeleteScript = nullptr;
+    QAction *mNewScript = nullptr;
+    QAction *mEditScript = nullptr;
+    QAction *mDesactivateScript = nullptr;
+    QAction *mRefreshList = nullptr;
+    QAction *mUploadScript = nullptr;
+    QAction *mGoToLine = nullptr;
+    QAction *mFindAction = nullptr;
+    QAction *mReplaceAction = nullptr;
+    QAction *mUndoAction = nullptr;
+    QAction *mRedoAction = nullptr;
+    QAction *mCopyAction = nullptr;
+    QAction *mPasteAction = nullptr;
+    QAction *mCutAction = nullptr;
+    QAction *mSelectAllAction = nullptr;
+    QAction *mSaveAsAction = nullptr;
+    QAction *mImportAction = nullptr;
+    QAction *mShareAction = nullptr;
+    QAction *mSpellCheckAction = nullptr;
+    QAction *mCheckSyntaxAction = nullptr;
+    QAction *mCreateRulesGraphicallyAction = nullptr;
+    QAction *mCommentAction = nullptr;
+    QAction *mUncommentAction = nullptr;
+    QAction *mZoomInAction = nullptr;
+    QAction *mZoomOutAction = nullptr;
+    QAction *mZoomResetAction = nullptr;
+    QAction *mDebugSieveScriptAction = nullptr;
+    QAction *mWrapTextAction = nullptr;
+    QAction *mPrintAction = nullptr;
+    QAction *mPrintPreviewAction = nullptr;
+    PimCommon::KActionMenuChangeCase *mMenuChangeCaseAction = nullptr;
 
-    QLabel *mStatusBarInfo;
-    SieveEditorBookmarks *mSieveEditorBookmarks;
-    KActionMenu *mBookmarkMenu;
-    bool mNetworkIsDown;
+    QLabel *mStatusBarInfo = nullptr;
+    SieveEditorBookmarks *mSieveEditorBookmarks = nullptr;
+    KActionMenu *mBookmarkMenu = nullptr;
+    bool mNetworkIsDown = false;
 };
 
 #endif // SIEVEEDITORMAINWINDOW_H
