@@ -22,6 +22,7 @@
 
 #include <QWidget>
 #include <QUrl>
+#include <KSieveUi/ManageSieveWidget>
 
 class SieveEditorManageSieveWidget;
 class QTreeWidgetItem;
@@ -41,7 +42,7 @@ public:
     void refreshList();
 
 Q_SIGNALS:
-    void createScriptPage(const QUrl &url, const QStringList &capabilities, bool isNewScript, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
+    void createScriptPage(const KSieveUi::ManageSieveWidget::ScriptInfo &info, bool isNewScript);
     void updateButtons(bool newScriptAction, bool editScriptAction, bool deleteScriptAction, bool desactivateScriptAction);
     void scriptDeleted(const QUrl &url);
     void serverSieveFound(bool hasServerSieve);
@@ -53,12 +54,12 @@ public Q_SLOTS:
     void slotRefreshList();
 
 private Q_SLOTS:
-    void slotNewScript(const QUrl &url, const QStringList &capabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
-    void slotEditScript(const QUrl &url, const QStringList &capabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
+    void slotNewScript(const KSieveUi::ManageSieveWidget::ScriptInfo &info);
+    void slotEditScript(const KSieveUi::ManageSieveWidget::ScriptInfo &info);
     void slotUpdateButtons(QTreeWidgetItem *item);
 
 private:
-    SieveEditorManageSieveWidget *mTreeView;
+    SieveEditorManageSieveWidget *mTreeView = nullptr;
 };
 
 #endif // SIEVEEDITORSCRIPTMANAGERWIDGET_H
