@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,7 +25,7 @@ class SieveEditorTabWidget : public QTabWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorTabWidget(KActionCollection *ac, QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorTabWidget(KActionCollection *ac, QWidget *parent = nullptr);
     ~SieveEditorTabWidget();
 
 Q_SIGNALS:
